package Log::ger::Manual;

our $DATE = '2017-08-02'; # DATE
our $VERSION = '0.021.002'; # VERSION

1;
# ABSTRACT: Manual for Log::ger

__END__

=pod

=encoding UTF-8

=head1 NAME

Log::ger::Manual - Manual for Log::ger

=head1 VERSION

version 0.021.002

=head1 DESCRIPTION

This distribution contains the following documentation pages:

=over

=item * L<Log::ger::Manual::FAQ>

=item * L<Log::ger::Manual::ForLog4perl>

=item * L<Log::ger::Manual::ForLogAny>

=item * L<Log::ger::Manual::ForLogContextual>

=item * L<Log::ger::Manual::ForLogDispatch>

=item * L<Log::ger::Manual::ForLogDispatchouli>

=item * L<Log::ger::Manual::Internals>

=item * L<Log::ger::Manual::Tutorial>

=item * L<Log::ger::Manual::Tutorial::01>

=item * L<Log::ger::Manual::Tutorial::02>

=item * L<Log::ger::Manual::Tutorial::03>

=item * L<Log::ger::Manual::Tutorial::04>

=item * L<Log::ger::Manual::Tutorial::05>

=back

Start with L<Log::ger::Manual::Tutorial>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
